@@ -93,6 +93,14 @@ makeDataDirPermanent db = db
 --   @since 1.12.0.0
 toTemporaryDirectory :: DB -> FilePath
 toTemporaryDirectory = resourcesTemporaryDir . dbResources
+
+{-|
+Get the final @postgresql.conf@
+
+@since 1.22.0.0
+-}
+toPostgresqlConf :: DB -> String
+toPostgresqlConf = completePlanConfig . resourcesPlan . dbResources
 -------------------------------------------------------------------------------
 -- Life Cycle Management
 -------------------------------------------------------------------------------
@@ -112,16 +120,16 @@ The fastest config we can make.
 
 @since 1.21.0.0
 -}
-fastPostgresConfig :: [String]
+fastPostgresConfig :: [(String, String)]
 fastPostgresConfig =
-  [ "shared_buffers = 12MB"
-  , "fsync = off"
-  , "synchronous_commit = off"
-  , "full_page_writes = off"
-  , "log_min_messages = PANIC"
-  , "log_min_error_statement = PANIC"
-  , "log_statement = none"
-  , "client_min_messages = ERROR"
+  [ ("shared_buffers", "12MB")
+  , ("fsync", "off")
+  , ("synchronous_commit", "off")
+  , ("full_page_writes", "off")
+  , ("log_min_messages", "PANIC")
+  , ("log_min_error_statement", "PANIC")
+  , ("log_statement", "none")
+  , ("client_min_messages", "ERROR")
   ]
 
 {-|
@@ -246,7 +254,7 @@ or with lenses:
 
 @since 1.21.0.0
 -}
-defaultPostgresConf :: [String] -> Config
+defaultPostgresConf :: [(String, String)] -> Config
 defaultPostgresConf extra = defaultConfig <> mempty
   { plan = mempty
     { postgresConfigFile = extra
@@ -256,16 +264,16 @@ defaultPostgresConf extra = defaultConfig <> mempty
 -- | Default postgres options
 --
 --   @since 1.21.0.0
-verbosePostgresConfig :: [String]
+verbosePostgresConfig :: [(String, String)]
 verbosePostgresConfig =
-  [ "shared_buffers = 12MB"
-  , "fsync = off"
-  , "synchronous_commit = off"
-  , "full_page_writes = off"
-  , "log_min_duration_statement = 0"
-  , "log_connections = on"
-  , "log_disconnections = on"
-  , "client_min_messages = WARNING"
+  [ ("shared_buffers", "12MB")
+  , ("fsync", "off")
+  , ("synchronous_commit", "off")
+  , ("full_page_writes", "off")
+  , ("log_min_duration_statement", "0")
+  , ("log_connections", "on")
+  , ("log_disconnections", "on")
+  , ("client_min_messages", "WARNING")
   ]
 
 {-|
@@ -279,6 +287,7 @@ verboseConfig = defaultConfig <> mempty
     { logger = pure print
     , postgresConfigFile = verbosePostgresConfig
     , initDbConfig = pure standardProcessConfig
+    , createDbConfig = pure standardProcessConfig
     , postgresPlan = mempty
         { postgresConfig = standardProcessConfig
         }
