@@ -215,9 +215,6 @@ data ProcessConfig = ProcessConfig
   deriving Semigroup via GenericSemigroup ProcessConfig
   deriving Monoid    via GenericMonoid ProcessConfig
 
-prettyHandle :: Handle -> Doc
-prettyHandle _ = text "[HANDLE]"
-
 instance Pretty ProcessConfig where
   pretty ProcessConfig {..}
     = text "environmentVariables:"
@@ -442,7 +439,7 @@ data Plan = Plan
   , copyConfig :: Last (Maybe CopyDirectoryCommand)
   , createDbConfig :: Accum ProcessConfig
   , postgresPlan :: PostgresPlan
-  , postgresConfigFile :: [String]
+  , postgresConfigFile :: [(String, String)]
   , dataDirectoryString :: Last String
   , connectionTimeout :: Last Int
   -- ^ Max time to spend attempting to connection to @postgres@.
@@ -471,12 +468,16 @@ instance Pretty Plan where
     <> hardline
     <> text "postgresConfigFile:"
     <> softline
-    <> indent 2 (vsep $ map text postgresConfigFile)
+    <> indent 2 (vsep $ map (\(x, y) -> text x <> "=" <> text y) postgresConfigFile)
     <> hardline
     <> text "dataDirectoryString:" <+> pretty (getLast dataDirectoryString)
     <> hardline
     <> text "connectionTimeout:" <+> pretty (getLast connectionTimeout)
 
+flattenConfig :: [(String, String)] -> String
+flattenConfig = unlines . map (\(x, y) -> x <> "=" <> y) .
+  Map.toList . Map.fromList
+
 -- | Turn a 'Plan' into a 'CompletePlan'. Fails if any values are missing.
 completePlan :: [(String, String)] -> Plan -> Either [String] CompletePlan
 completePlan envs Plan {..} = do
@@ -498,7 +499,7 @@ completePlan envs Plan {..} = do
         <*> getOption "dataDirectoryString" dataDirectoryString
         <*> getOption "connectionTimeout" connectionTimeout
 
-  let completePlanConfig = unlines postgresConfigFile
+  let completePlanConfig = flattenConfig postgresConfigFile
       completePlanCopy = completeCopyDirectory completePlanDataDirectory <$>
         join (getLast copyConfig)
 
@@ -560,10 +561,10 @@ instance Pretty Config where
     <> hardline
     <> text "initDbCache:" <+> pretty (getLast initDbCache)
 
-socketDirectoryToConfig :: FilePath -> [String]
+socketDirectoryToConfig :: FilePath -> [(String, String)]
 socketDirectoryToConfig dir =
-    [ "listen_addresses = '127.0.0.1, ::1'"
-    , "unix_socket_directories = '" <> dir <> "'"
+    [ ("listen_addresses", "'127.0.0.1,::1'")
+    , ("unix_socket_directories", "'" <> dir <> "'")
     ]
 
 -------------------------------------------------------------------------------
@@ -738,7 +739,7 @@ toPlan _makeInitDb makeCreateDb port socketDirectory dataDirectoryString = mempt
           }
       }
   , createDbConfig = if makeCreateDb
-      then pure $ silentProcessConfig
+      then pure silentProcessConfig
         { commandLine = mempty
             { keyBased = Map.fromList
                 [ ("-h", Just socketDirectory)
@@ -748,7 +749,7 @@ toPlan _makeInitDb makeCreateDb port socketDirectory dataDirectoryString = mempt
         }
       else mempty
 
-  , initDbConfig = pure $ silentProcessConfig
+  , initDbConfig = pure silentProcessConfig
         { commandLine = mempty
             { keyBased = Map.fromList
                 [("--pgdata=", Just dataDirectoryString)]
@@ -757,22 +758,6 @@ toPlan _makeInitDb makeCreateDb port socketDirectory dataDirectoryString = mempt
   , copyConfig = pure Nothing
   }
 
-
--- | 'combinePlans' is almost '<>'. However the 'Last' monoid for
---    @createdb@ and @initdb@ plans are not used. Instead something
---    like Lastoid is.
-combinePlans :: Plan -> Plan -> Plan
-combinePlans x y = Plan
-  { logger               = logger x              <> logger y
-  , initDbConfig         = initDbConfig x        <> initDbConfig y
-  , copyConfig           = copyConfig x          <> copyConfig y
-  , createDbConfig       = createDbConfig x      <> createDbConfig y
-  , postgresPlan         = postgresPlan x        <> postgresPlan y
-  , postgresConfigFile   = postgresConfigFile x  <> postgresConfigFile y
-  , dataDirectoryString  = dataDirectoryString x <> dataDirectoryString y
-  , connectionTimeout    = connectionTimeout x   <> connectionTimeout y
-  }
-
 -- | Create all the temporary resources from a 'Config'. This also combines the
 -- 'Plan' from 'toPlan' with the @extra@ 'Config' passed in.
 setupConfig
@@ -794,7 +779,7 @@ setupConfig Config {..} = evalContT $ do
         thePort
         (toFilePath resourcesSocketDirectory)
         (toFilePath resourcesDataDir)
-      finalPlan = combinePlans hostAndDir plan
+      finalPlan = hostAndDir <> plan
   uncachedPlan <- lift $
     either (throwIO . CompletePlanFailed (show $ pretty finalPlan)) pure $
       completePlan envs finalPlan
@@ -1057,7 +1042,7 @@ postgresConfigL
 -- | Lens for 'postgresConfigFile'.
 --
 --   @since 1.12.0.0
-postgresConfigFileL :: Lens' Plan [String]
+postgresConfigFileL :: Lens' Plan [(String, String)]
 postgresConfigFileL f plan@Plan{..}
   = fmap (\x -> plan { postgresConfigFile = x })
       (f postgresConfigFile)
